# --- begin comments by J. Stolfi --------------------------
# Last edited on 1998-10-09 22:22:28 by stolfi
#
# Mapping the interlinear file to the EVA encoding
# Jorge Stolfi 05 Nov 1997 (Corrected 31 Mar 1998)
#
# This transformation was done with "fsg2eva", an AWK
# script. The main step is the following:
#
#   function fsg_to_eva(txt)
#   {
#     # Converts a chunk of comment-free FSG text to EVA
#     
#     # We discard  "%" and "!" since the conversion
#     # will destroy synchronism anyway.
#     gsub(/[% !]/, "", txt);
#     
#     # Now convert 
#     gsub(/IIIE/, "iiil",  txt);
#     gsub(/IIIK/, "iiim",  txt);
#     gsub(/IIIL/, "iiin",  txt);
#     gsub(/IIIR/, "iiir",  txt);
#     gsub(/IIE/,  "iil",   txt);
#     gsub(/IIK/,  "iim",   txt);
#     gsub(/IIL/,  "iin",   txt);
#     gsub(/IIR/,  "iir",   txt);
#     gsub(/IE/,   "il",    txt);
#     gsub(/IK/,   "im",    txt);
#     gsub(/IL/,   "in",    txt);
#     gsub(/IR/,   "ir",    txt);
#     gsub(/HZ/,   "cth",   txt);
#     gsub(/PZ/,   "cph",   txt);
#     gsub(/DZ/,   "ckh",   txt);
#     gsub(/FZ/,   "cfh",   txt);
#     gsub(/2/,    "s",     txt);
#     gsub(/4/,    "q",     txt);
#     gsub(/6/,    "g",     txt);
#     gsub(/7/,    "j",     txt);
#     gsub(/8/,    "d",     txt);
#     gsub(/A/,    "a",     txt);
#     gsub(/C/,    "e",     txt);
#     gsub(/D/,    "k",     txt);
#     gsub(/E/,    "l",     txt);
#     gsub(/F/,    "f",     txt);
#     gsub(/G/,    "y",     txt);
#     gsub(/H/,    "t",     txt);
#     gsub(/I/,    "i",     txt);
#     gsub(/K/,    "m",     txt);
#     gsub(/L/,    "n",     txt);
#     gsub(/M/,    "iin",   txt);
#     gsub(/N/,    "in",    txt);
#     gsub(/O/,    "o",     txt);
#     gsub(/P/,    "p",     txt);
#     gsub(/R/,    "r",     txt);
#     gsub(/S/,    "sh",    txt);
#     gsub(/T/,    "ch",    txt);
#     gsub(/V/,    "v",     txt);
#     gsub(/Y/,    "x",     txt);
#     
#     return txt
#   }
#
# This procedure was applied to the Voynich text proper, preserving
# the '#' and '{}' comments as well as the location codes.
#
# I had to edit manually some '{}' comments that contained Voynich
# characters in FSG or Currier notation.  The affected pages are
#
#   f100r.P1  f100r.m  f100v.M  f103r.P  f104r.P  f49v.P  f65v.P
#   f66r.R    f76r.R   f89r1.b  f89r2.b  
#
# Note: The 05 Nov 1997 version of this script incorrectly mapped "IK" to
# "ik" instead of "im". This error affected 79 lines of Gabriel Landini's
# interlinar v1.6, representing about 50 distinct words. The error was
# corrected on 31 Mar 1998, by manually editing the EVA translation of
# those lines. The endings "IIIK", "IIK", and "K" were not affected by
# this error.
#
# The following is a cumulative list of other format and alignment bugs 
# that were fixed by hand in the EVA translation, up to 05 may 1998:
#   
#   <f8r.P2.10;F>   added "m" at end of line.
#   <f8r.P2.11;F>   deleted "m." at beginning of line.
#   <f8r.T2.13;F>   added "m" at end of line.
#   <f8r.P3.14;F>   deleted "m." at beginning of line.
#   <f8r.P3.17;F>   deleted whole line.
#   <f8r.P3.18;F>   added "okar." at beginning of line.
#   
#   <f11v.P.1;C>    replaced "." by "-" between words 4 and 5.
#   <f11v.P.1;F>    replaced "." by "-" between words 4 and 5.
#   <f11v.P.2;C>    replaced "." by "-" between words 6 and 7.
#   <f11v.P.2;F>    replaced "." by "-" between words 6 and 7.
#   <f11v.P.3;C>    replaced "." by "-" between words 6 and 7.
#   <f11v.P.3;F>    replaced "." by "-" between words 6 and 7.
#   <f11v.P.4;C>    replaced "." by "-" between words 5 and 6.
#   <f11v.P.4;F>    replaced "." by "-" between words 5 and 6.
#   <f11v.P.4;F>    added "on" at end of line.
#   <f11v.P.5;C>    replaced "." by "-" between words 6 and 7.
#   <f11v.P.5;F>    replaced "." by "-" between words 5 and 6.
#   <f11v.P.5;F>    deleted "on." from beginning of line.
#   <f11v.P.5;F>    added "m" at end of line.
#   <f11v.P.6;F>    deleted "m." from beginning of line.
#
#   <f13r.P.1;F>    added "m" at end of line.
#   <f13r.P.2;F>    deleted "m." at beginning of line.
# 
#   <f14r.P.12;F>   added "m" at end of line.
#   <f14r.P.13;F>   deleted "m" at beginning of line.
#   
#   <f14v.P.8;C>    replaced "." by "-" between words 2 and 3.
#   <f14v.P.8;F>    replaced "." by "-" between words 2 and 3.
#   <f14v.P.9;C>    replaced "." by "-" between words 2 and 3.
#   <f14v.P.9;F>    replaced "." by "-" between words 2 and 3.
#   
#   <f15v.P.7;F>    added "s" at end of line.
#   <f15v.P.8;F>    deleted "s." at beginning of line.
#   
#   <f17v.P.16;F>   added "m" at end of line.
#   <f17v.P.17;F>   deleted "m." at beginning of line.
#   
#   <f18r.P.2;F>    added "iiin" at end of line.
#   <f18r.P.3;F>    deleted "iiin." at beginning of line.
#   <f18r.P.3;F>    added "m" at end of line.
#   <f18r.P.4;F>    deleted "m." at beginning of line.
#   
#   <f18v.P.4;F>    added "r" at end of line.
#   <f18v.P.5;F>    deleted "r." from beginning of line.
#   
#   <f19v.P.6;C>    replaced by "{missing line}" comment.
#   <f19v.P.6;F>    truncated after "chocthy.s".
#   <f19v.P.6a;C>   new line, same as old <f19v.P.6;C>.
#   <f19v.P.6a;F>   new line, with the part of old <f19v.P.6;F> after "chocthy.s".
#
#   <f20v.P.7;C>    replaced "." by "-" between words 7 and 8.
#   <f20v.P.7;F>    replaced "." by "-" between words 7 and 8.
#   <f20v.P.10;F>   deleted "*." at beginning of line.
# 
#   <f21v.P.4;C>    replaced "." by "-" between words 7 and 8.
#   <f21v.P.4;F>    replaced "." by "-" between words 7 and 8.
#   
#   <f22v.P.1;C>    replaced "." by "-" between words 5 and 6.
#   <f22v.P.1;F>    replaced "." by "-" between words 5 and 6.
#   <f22v.P.2;C>    replaced "." by "-" between words 5 and 6.
#   <f22v.P.2;F>    replaced "." by "-" between words 5 and 6.
#   <f22v.P.3;C>    replaced "." by "-" between words 5 and 6.
#   <f22v.P.3;F>    replaced "." by "-" between words 6 and 7.
#   <f22v.P.4;C>    replaced "." by "-" between words 3 and 4, 5 and 6.
#   <f22v.P.4;F>    replaced "." by "-" between words 3 and 4, 5 and 6.
#   
#   <f23r.P.7;F>    added "m" at end of line.
#   <f23r.P.8;F>    deleted "m." at beginning of line.
#   
#   <f23v.P.2;C>    replaced "." by "-" between words 5 and 6.
#   <f23v.P.2;F>    replaced "." by "-" between words 6 and 7.
#   <f23v.P.3;C>    replaced "." by "-" between words 7 and 8.
#   <f23v.P.3;F>    replaced "." by "-" between words 7 and 8.
#   <f23v.P.4;C>    replaced "." by "-" between words 5 and 6.
#   <f23v.P.4;F>    replaced "." by "-" between words 4 and 5.
#   
#   <f24r.P.4;F>    added "a" at end of line.
#   <f24r.P.5;F>    deleted "a." at beginning of line.
#   
#   <f24v.P.4;F>    deleted "y." at beginning of line.
#   <f24v.P.4;F>    deleted ".oeor" at end of line.
#   <f24v.P.5;F>    added "oeor." at beginning of line.
#   
#   <f25r.P.3;F>    added "in" at end of line.
#   <f25r.P.4;F>    deleted "in." at beginning of line.
#   
#   <f26r.P.2;F>    added "r" at end of line.
#   <f26r.P.3;F>    deleted "r." at beginning of line.
#   
#   <f27r.P.9;F>    added "m" at end of line.
#   <f27r.P.10;F>   deleted "m." at beginning of line.
#   
#   <f27v.P.4;F>    bogus "=" in middle of line; replaced by ".".
#   <f27v.P.5;C>    replaced by "{missing line}" comment.
#   <f27v.P.5;F>    truncated after "ctho.dol".
#   <f27v.P.6;C>    added old <f27v.P.5;C> at beginning of line.
#   <f27v.P.6;F>    added the truncated part of old <f27v.P.5;F> at beginning of line.
#   
#   <f28v.P2.7;C>   replaced "." by "-" between words 6 and 7.
#   <f28v.P2.7;F>   replaced "." by "-" between words 6 and 7.
#   
#   <f29v.P.4;F>    replaced "." by "-" between words 6 and 7.
#   <f29v.P.4;F>    deleted "-" between words 7 and 8.
#   <f29v.P.5;C>    replaced "." by "-" between words 3 and 4.
#   <f29v.P.5;F>    replaced "." by "-" between words 3 and 4.
#   <f29v.P.6;C>    replaced "." by "-" between words 5 and 6.
#   <f29v.P.6;F>    replaced "." by "-" between words 5 and 6.
#   <f29v.P.6;C>    replaced "." by "-" between words 7 and 8.
#   <f29v.P.6;F>    replaced "." by "-" between words 7 and 8.
#   <f29v.P.7;C>    deleted extra "-" between words 5 and 6.
#   <f29v.P.7;F>    deleted "--" between words 5 and 6.
#   <f29v.P.7;F>    replaced "." by "-" between words 5 and 6.
#   <f29v.P.8;C>    replaced "." by "-" between words 4 and 5.
#   <f29v.P.8;F>    replaced "." by "-" between words 5 and 6.
#   <f29v.P.9;C>    replaced "." by "-" between words 6 and 7.
#   <f29v.P.9;F>    replaced "." by "-" between words 6 and 7.
#   <f29v.P.10;C>   replaced "." by "-" between words 3 and 4.
#   <f29v.P.10;C>   replaced "." by "-" between words 4 and 5.
#   <f29v.P.10;F>   replaced "." by "-" between words 3 and 4.
#   <f29v.P.10;F>   inserted "-" in word 4 between "cth" and "chyd".
#   
#   <f30r.P.3;F>    added "im" at end of line.
#   <f30r.P.4;F>    deleted "im." from beginning of line.
#   <f30r.P.12;F>   added "iin" at end of line.
#   <f30r.P.13;F>   deleted "iin." at beginning of line.
#   
#   <f31r.P.15;F>   added "r" at end of line.
#   <f31r.T.16;F>   deleted "r." at beginning of line.
#   
#   <f31v.P.2;F>    deleted starting from "ykeeo"
#   <f31v.P.3;F>    created from parts of lines 2 and 4.
#   <f31v.P.4;F>    deleted up to "lkedy".
#   <f31v.P.4;F>    added "m" at end of line.
#   <f31v.P.5;F>    deleted "m." at beginning of line.
#   
#   <f32r.P.2;F>    added "f" at end of line.
#   <f32r.P.3;F>    deleted "f." at beginning of line.
#   
#   <f33v.P.1;C>    replaced "." by "-" between words 2 and 3.
#   <f33v.P.1;F>    replaced "." by "-" between words 2 and 3. 
#   <f33v.P.1;F>    added ".es" at end of line.
#   <f33v.P.2;F>    deleted "es." from beginning of line.
#   <f33v.P.2;C>    replaced "." by "-" between "oky" and "otal.
#   <f33v.P.2;F>    replaced "." by "-" between "oky" and "otal.
#   <f33v.P.4;F>    added "iin" at end of line.
#   <f33v.P.5;F>    deleted "iin." at beginning of line.
#   <f33v.P.7;C>    replaced "." by "-" between "oky" and "cheol".
#   <f33v.P.7;F>    replaced "." by "-" between "oky" and "cheol".
#   <f33v.P.8;C>    replaced "." by "-" between "chy" and "daiin".
#   <f33v.P.8;F>    replaced "." by "-" between "chy" and "daiin".
#   <f33v.P.9;C>    replaced "." by "-" between "chckhy" and "ar.aiin".
#   <f33v.P.9;F>    replaced "." by "-" between "chckhy" and "ar.aiin".
#   <f33v.P.9;C>    replaced ".-" by "-".
#   <f33v.P.9;F>    replaced ".-" by "-".
#
#   <f34r.P.7;F>    moved "iir.amm." to end of line.
#   <f34r.P.9;F>    "chZt" replaced by "chcth" (from ";C>" version).
#   
#   <f37r.P.10;F>   added "iir" at end of line.
#   <f37r.P.11;F>   deleted "iir." at beginning of line.
#   
#   <f37v.P.15;F>   added "in" at end of line.
#   <f37v.P.16;F>   deleted "in." at beginning of line.
#   
#   <f39r.P.4;F>    added "m" at end of line.
#   <f39r.P.5;F>    deleted "m." at beginning of line.
#   
#   <f39v.P.10;F>   added "p" at end of line.
#   <f39v.P.11;F>   deleted "p." at beginning of line.
#   
#   <f40r.P.8;F>    added "m" at end of line.
#   <f40r.P.9;F>    deleted "m." from beginning of line.
#   
#   <f40v.P.7;F>    added "r" at end of line.
#   <f40v.P.8;F>    deleted "r." at beginning of line.
#
#   <f42r.P.15;F>   bogus "=" in middle of line; split off piece as line 14a.
#   
#   <f42v.P.4;F>    added "m" at end of line.
#   <f42v.P.4;G>    added "m" at end of line.
#   <f42v.P.5;F>    deleted "m." at beginning of line.
#   <f42v.P.5;G>    deleted "m." at beginning of line.
#
#   <f43r.P.4;G>    leading ".", deleted.
#   <f43r.P.8;F>    replaced "-d.dshedy" on by "d-".
#   <f43r.P.8;G>    deleted from "-d.dshedy" on.
#   <f43r.P.9;F>    replaced by part of line 8 from "dshedy" on.
#   <f43r.P.9;C>    replaced by <f43v.P.1;C>.
#   <f43r.P.12;F>   added "iin" at end of line.
#   <f43r.P.13;F>   deleted "iin." at beginning of line.
#   <f43r.P.13;G>   deleted "iin." at beginning of line.
#   
#   <f43v.P.1;C>    replaced by <f43r.P.9;C>.
#   <f43v.P.2;F>    deleted "y." at beginning of line.
#   <f43v.P.1;F>    added "y" at end of line.
#   <f43v.P.1;G>    added "y" at end of line.
#    
#   <f44v.P.5;F>    added "in" at end of line.
#   <f44v.P.5;G>    added "in" at end of line.
#   <f44v.P.6;F>    deleted "in." at beginning of line.
#   <f44v.P.6;G>    deleted "in." at beginning of line.
#    
#   <f45r.P.8;F>    added ".m" at end of line.
#   <f45r.P.8;G>    added ".m" at end of line.
#   <f45r.P.9;F>    deleted "m." at beginning of line.
#   <f45r.P.9;G>    deleted "m." at beginning of line.
#    
#   <f45v.P.6;F>    added "m" at end of line.
#   <f45v.P.6;G>    added "m" at end of line.
#   <f45v.P.7;F>    deleted "m." at beginning of line.
#
#   <f46v.P.7;G>    duplicate ".", replaced by single ".".
#   
#   <f47v.P.9;F>    added "iin" at end of line.
#   <f47v.P.10;F>   deleted "iin." at beginning of line.
#   <f47v.P.10;G>   deleted "iin." at beginning of line.
#   <f47v.P.12;F>   duplicate ".", replaced by single ".".
#   <f47v.P.12;G>   leading ".", deleted.
#
#   <f48v.P.7;F>    bogus "=" in middle of line; replaced by ".".
#   <f48v.P.7;F>    added "y" at end of line.
#   <f48v.P.8;F>    deleted "y." at beginning of line.
#   <f48v.P.8;G>    deleted "y." at beginning of line.
#   
#   <f49r.P.20;F>   added "iin" at end of line.
#   <f49r.P.21;F>   deleted "iin." at beginning of line.
#   <f49r.P.21;G>   deleted "iin." at beginning of line.
#   
#   <f49v.P.16;F>   added "m" at end of line.
#   <f49v.P.16;G>   added "m" at end of line.
#   <f49v.P.17;F>   deleted "m." from beginning of line. 
#   <f49v.P.17;G>   deleted "m." from beginning of line. 
#   <f49v.P.19;F>   added "m" at end of line.
#   <f49v.P.19;G>   added "m" at end of line.
#   <f49v.P.20;F>   deleted "m." from beginning of line. 
#   <f49v.P.20;G>   deleted "m." from beginning of line. 
#   <f49v.P.23;F>   added ".r" at end of line.
#   <f49v.P.23;G>   added ".r" at end of line.
#   <f49v.P.24;F>   deleted "r." from beginning of line. 
#   <f49v.P.24;G>   deleted "r." from beginning of line. 
#
#   <f51r.P.7;F>    added "l" at end of line.
#   <f51r.P.7;G>    added "l" at end of line.
#   <f52r.P.8;F>    deleted "l." from beginning of line. 
#   
#   <f51v.P.4;F>    added "m" at end of line.
#   <f51v.P.4;F>    added "m" at end of line.
#   <f51v.P.5;F>    deleted "m." from beginning of line. 
#
#   <f52r.P.7;F>    added "l" at end of line.
#   <f52r.P.7;G>    added "l" at end of line.
#   <f52r.P.8;F>    deleted "l." from beginning of line. 
#   <f52r.P.8;G>    deleted "l." from beginning of line. 
#   
#   <f52v.P.5;F>    added "m" at end of line.
#   <f52v.P.6;F>    deleted "m." at beginning of line.
#   
#   <f53v.P.2;F>    added "y" at end of line.
#   <f53v.P.3;F>    deleted "y." at beginning of line.
#   
#   <f54r.P.6;F>    added "ar" at end of line.
#   <f54r.P.7;F>    deleted "ar." at beginning of line.
#   
#   <f54v.P.8;C>    deleted bogus text after "okal.om-".
#   <f54v.P.8;F>    deleted "y-" at end of line.
#   <f54v.P.9;F>    added "y" at beginning of line.
#   
#   <f55r.P.11;F>   added "iin" at end of line.
#   <f55r.P.12;F>   deleted "iin." at beginning of line.
#   
#   <f55v.P.11;F>   added "iin" at end of line.
#   <f55v.P.12;F>   deleted "iin." at beginning of line.
#   
#   <f56v.P.4;F>    added "iin" at end of line.
#   <f56v.P.5;F>    deleted "iin." at beginning of line.
#   <f56v.P.12;F>   added "iin" at end of line.
#   <f56v.P.13;F>   deleted "iin." at beginning of line.
#   
#   <f66r.L.14;F>   bogus FSG "Z", replaced by "*".
#
#   <f66r.R.3;C>    duplicate ".", replaced by single ".".
#
#   <f66v.P.7;F>    bogus FSG "J", replaced by "*".
#
#   <f68r1.P.3;C>   added "okeey.rar.eckhear.daraj-" at end of line.
#   <f68r1.P.3;F>   added "okey.ror.chckhar.daram-" at end of line.
#   <f68r1.P.4;C>   deleted "okeey.rar.eckhear.daraj-" from end of line.
#   <f68r1.P.4;F>   deleted "okey.ror.chckhar.daram-" from end of line.
#
#   <f68v2.C.1;C>   replaced by join of C.1 thru C.4, with new break at 10:30.
#   <f68v2.C.1;D>   replaced by join of D.1 and C2 thru C.4, with new break at 10:30.
#   <f68v2.C.2;C>   deleted line.
#   <f68v2.C.3;C>   deleted line.
#   <f68v2.C.4;C>   deleted line.
#
#   <f68v3.P.0;F>   deleted ".sshey" from end of line.
#   <f68v3.P.1;F>   added "sshey." at beginning of line.
#
#   <f70r2.P.4;F>   bogus FSG "Z", replaced by "*".
#   <f70r2.P.9;F>   deleted "qokal.chol...cheey.okal-" from end of line.
#   <f70r2.P.9a;F>  created line with "{crease}qokal.chol...cheey.okal-".
#   <f70r2.P.10;F>  deleted "qokal.shkal...qokal.chdy-" from end of line.
#   <f70r2.P.10a;F> created line "qokal.shkal...qokal.chdy-".
#   <f70r2.P.11;F>  deleted "okaiin.chcthey.s.or.ary=" frm end of line.
#   <f70r2.P.11a;F> created line with "okaiin.chcthey.s.or.ary=".
#
#   <f75r.P.7;F>    added right half of <f75r.P.8;F>.
#   <f75r.P.8;F>    replaced right half by right half of <f75r.P.9;F>.
#   <f75r.P.9;F>    deleted right half.
#
#   <f75v.P.28;C>   leading ".", deleted.
#
#   <f76r.R.5;F>    added "r" at end of line.
#
#   <f76r.L.6;F>    deleted "r." at beginning of line.
#   <f76r.L.13;F>   deleted "ir." at beginning of line.
#   <f76r.L.14;F>   added "o" label.
#   <f76r.L.15;F>   deleted "o" label.
#   <f76r.L.26;F>   deleted "r" label.
#   <f76r.L.38;F>   deleted "iin" label.
#
#   <f76r.R.12;F>   added "ir" at end of line.
#   <f76r.R.14;F>   added "dchedy.qolchey.qokefy" from line <f76r.R.15;F>.
#   <f76r.R.15;F>   deleted "dchedy.qolchey.qokefy" from beginning of line.
#   <f76r.R.25;F>   added "r" at end of line.
#   <f76r.R.33;F>   added ".lchedy.qolain....otalam" at end of line. 
#   <f76r.R.34;F>   deleted "lchedy.qolain....otalam." at beginning of line. 
#   <f76r.R.37;F>   added "iin" at end of line.
#   
#   <f77v.P.28;F>   added "iin" at end of line.
#   <f77v.P.29;F>   deleted "iin." at beginning of line.
#
#   <f78r.P.7;F>    deleted ".dar.alocfhy" at end of line.
#   <f78r.P.11;F>   deleted ".dchedaly" at end of line.
#   <f78r.P.24;F>   deleted ".otarodl.shy.orory" at end of line.
#   
#   <f78r.X.4;F>    added line "dchedaly=" from <f78r.P.11;F>.
#   <f78r.X.3;F>    added line "dar.alocfhy=" from <f78r.P.7;F>.
#   <f78r.X.5;F>    added line "otarodl.shy.orory=" from <f78r.P.24;F>.
#
#   <f78v.P.3;F>    added "m" at end of line.
#   <f78v.P.4;F>    deleted "m." at beginning of line.
#   <f78v.P.8;F>    added "iin" at end of line.
#   <f78v.P.9;F>    deleted "iin." at beginning of line.
#   <f78v.P.15;F>   added "s" at end of line.
#   <f78v.P.16;F>   deleted "s." at beginning of line.
#   
#   <f79r.P.9;F>    added "m" at end of line.
#   <f79r.P.10;F>   deleted "m." at beginning of line.#
#   <f79r.P.14;F>   added ".cheey.chey.daiin.chedy.qol" at end of line.
#   <f79r.P.15;F>   deleted "cheey.chey.daiin.chedy.qol." at beginning of line.
#   <f79r.P.16;F>   added "m" at end of line.
#   <f79r.P.17;F>   deleted "m." at beginning of line.
#   <f79r.P.30;F>   deleted bogus "-" in "olon".
#   
#   <f79v.P.8;F>    added "l" at end of line.
#   <f79v.P.9;F>    deleted "l" at beginning of line.
#   <f79v.P.13;F>   added "m" at end of line.
#   <f79v.P.14;F>   deleted "m." at beginning of line.
#   <f79v.P.15;F>   added "iin" at end of line.
#   <f79v.P.16;F>   deleted "iin." at beginning of line.
#   <f79v.P.18;F>   deleted ".y" from linendof line.
#   <f79v.P.19;F>   added "y" at beginning of line.
#   <f79v.P.26;F>   added "*" at end of line.
#   <f79v.P.27;F>   deleted "*." at beginning of line.
#   <f79v.P.31;F>   added "iin" at end of line.
#   <f79v.P.32;F>   deleted "iin." at beginning of line.
#   <f79v.P.38;F>   added "m" at end of line.
#   <f79v.P.39;F>   deleted ""m."" at beginning of line.
#   <f79v.P.41;F>   added "iin" at end of line.
#   <f79v.P.42;F>   deleted "iin." at beginning of line.
#   
#   <f80r.P.2;F>    added "s" at end of line.
#   <f80r.P.3;F>    deleted "s." at beginning of line.
#   <f80r.P.3;F>    added "m" at end of line.
#   <f80r.P.4;F>    deleted "m." at beginning of line.
#   <f80r.P.7;F>    added "m" at end of line.
#   <f80r.P.8;F>    deleted "m." at beginning of line.
#   <f80r.P.10;F>   added "m" at end of line.
#   <f80r.P.11;F>   deleted "m." at beginning of line.
#   <f80r.P.16;F>   deleted whole line.
#   <f80r.P.17;F>   added "qol." in front from pev line.
#   <f80r.P.38;F>   added "m" at end of line.
#   <f80r.P.39;F>   deleted "m." at beginning of line.
#   <f80r.P.41;F>   added "***.*" at beginning of line.
#   <f80r.P.40;F>   replaced "o-" by "o**-"
#   
#   <f80v.P.14;F>   added "r" at end of line.
#   <f80v.P.15;F>   deleted "r." at beginning of line.
#   <f80v.P.21;F>   added "m" at end of line.
#   <f80v.P.22;F>   deleted "m." at beginning of line.
#   <f80v.P.33;F>   added "m" at end of line.
#   <f80v.P.34;F>   deleted "m." at beginning of line.
#   <f80v.P.31;F>   added "iin" at end of line.
#   <f80v.P.32;F>   deleted "iin." at beginning of line.
#   
#   <f81r.P.5;F>    added "iin" at end of line.
#   <f81r.P.6;F>    deleted "iin." at beginning of line.
#   <f81r.P.7;F>    added "iin" at end of line.
#   <f81r.P.8;F>    deleted "iin." at beginning of line.
#
#   <f81v.P.4;F>    added "y" at end of line.
#   <f81v.P.5;F>    deleted "y." at beginning of line.
#
#   <f81v.P.5;F>    added ".kar.daiin.okar" at end of line.
#   <f81v.P.6;F>    deleted "kar.daiin.okar." at beginning of line.
#
#   <f81v.P.15;F>   added "*{skipped text}" after ".chedy.o"
#   <f81v.P.15;F>   deleted ".qor." at end of line.
#   <f81v.P.16;F>   added "qor." at beginning of line.
#   
#   <f82r.P2.31;F>  added "iin" at end of line.
#   <f82r.P2.32;F>  deleted "iin." at beginning of line.
#   
#   <f82v.P.21;F>   added "***." at beginning of line.
#   <f82v.P.30;F>   added "iin" at end of line.
#   <f82v.P.31;F>   deleted "iin." at beginning of line.
#   
#   <f83r.P.11;F>   added "o" at end of line.
#   <f83r.P.12;F>   deleted "o." at beginning of line.
#   <f83r.P.25;F>   added "l" at end of line.
#   <f83r.P.26;F>   deleted "l." at beginning of line.
#   <f83r.P.30;F>   added "iin" at end of line.
#   <f83r.P.31;F>   deleted "iin." at beginning of line.
#   <f83r.P.33;F>   added "iin" at end of line.
#   <f83r.P.34;F>   deleted "iin." at beginning of line.
#   <f83r.P.32;F>   split part to "shedal" as line <f83r.X.3;F>
#   <f83r.P.33;F>   split part to "chdal aiin" as line <f83r.X.4;F>
#   <f83r.P.34;F>   split part to "chedy" as line <f83r.X.5;F>
#   
#   <f83v.P.14;F>   deleted "qokain.cheeal" (nothing left on the line).
#   <f83v.P.15;F>   added "qokain.cheeal." at beginning of line.
#   <f83v.P.16;F>   deleted ".chedy.qol" at end of line.
#   <f83v.P.17;F>   added "chedy.qol" at beginning of line.
#   <f83v.P.20;F>   added "s" at end of line.
#   <f83v.P.21;F>   deleted "s." at beginning of line.
#   <f83v.P.25;F>   added "s" at end of line.
#   <f83v.P.26;F>   deleted "s." at beginning of line.
#   
#   <f84r.P.16;F>   added "iin" at end of line.
#   <f84r.P.17;F>   deleted "iin." at beginning of line.
#   <f84r.P.18;F>   deleted "otaly." at beginning of line.
#   <f84r.P.30;F>   deleted up to first "shedy.saiin.".
#
#   <f84r.X.13;F>   added "otaly=" from <f84r.P.18;F>.
#   
#   <f84v.P.12;F>   added "iin" at end of line.
#   <f84v.P.13;F>   deleted "iin." at beginning of line.
#   <f84v.P.20;F>   added "-okar" at end of line.
#   <f84v.P.21;F>   added "-ydairol" at end of line.
#   <f84v.P.21;F>   deleted "okar." at beginning of line.
#   <f84v.P.22;F>   added "-ychckhy" at end of line.
#   <f84v.P.22;F>   deleted "ydairol." at beginning of line.
#   <f84v.P.23;F>   added "-dshedy" at end of line.
#   <f84v.P.23;F>   deleted "ychckhy." at beginning of line.
#   <f84v.P.24;F>   deleted "dshedy." at beginning of line.
#   <f84v.P.30;F>   added "-okchdy" at end of line.
#   <f84v.P.31;F>   added "-solchey" at end of line.
#   <f84v.P.31;F>   deleted "okchdy." at beginning of line.
#   <f84v.P.32;F>   added "-dairoldy" at end of line.
#   <f84v.P.32;F>   deleted "solchey." at beginning of line.
#   <f84v.P.33;F>   added "-dorchy" at end of line.
#   <f84v.P.33;F>   deleted "dairoldy." at beginning of line.
#   <f84v.P.34;F>   added "-qckhy" at end of line.
#   <f84v.P.34;F>   deleted "dorchy." at beginning of line.
#   <f84v.P.35;F>   added "-ochedy" at end of line.
#   <f84v.P.35;F>   added "s" at end of line.
#   <f84v.P.35;F>   deleted "qckhy." at beginning of line.
#   <f84v.P.36;F>   deleted "ochedy." at beginning of line.
#   <f84v.P.36;F>   deleted "s." at beginning of line.
#
#   <f86v4.P.4;F>   deleted ".dar.oleey.olyy" from end of line.
#   <f86v4.P.5;F>   new line with "{centered -- "title"?}dar.oleey.olyy=".
#
#   <f86v6.P.22;F>  bogus FSG "X", replaced by "*".
#
#   <f86v3.P.4;F>   added "ykaiin{skipped line}m" at beginning of line
#   <f86v3.P.5;F>   deleted "ykaiinm." from beginning of line.
#
#   <f99v.P.12;F>   leading ".", deleted.
#
#   <f102v1.P1.6;F> deleted ".toiin.ol.daiin-" at end of line.
#   <f102v1.P1.6;F> added "=" at end of line.
#   <f102v1.P1.7;F> added "toiin.ol.daiin." at beginning of line.
#
#   <f103r.P.1;J>   leading ".", deleted.
#   <f103r.P.2;J>   leading ".", deleted.
#   <f103r.P.2;I>   leading ".", deleted.
#   <f103r.P.3;J>   leading ".", deleted.
#   
#   <f104r.P.7;J>   leading ".", deleted.
#   <f104r.P.8;J>   leading ".", deleted.
#
#   <f105r.P.16;F>  leading ".", deleted.
#
#   <f105v.P.15;F>  added ".r" at end of line.
#   <f105v.P.16;F>  deleted "r." at beginning of line.
#   
#   <f107r.P.33;T>  duplicate ".", replaced by single ".".
#   
#   <f112v.P.44;G>  leading ".", deleted.
#
#   <f116r.P.28;F>  bogus FSG "Z", replaced by "*".
#
# --- end comments by J. Stolfi ----------------------------
